Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| SAULO PAPALIA DA SILVA
CNPJ: 27.803.795/0001-22 Inscrição Estadual: 1090394842
RUA PREFEITO EVANDRO BEHR, 6755, CAMOBI, Santa Maria, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 54753 Série: 1 Data de Emissão: 05/11/2019 21:00:46
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4319 1127 8037 9500 0122 6500 1000 0547 5310 8611 4540
Protocolo de Autorização: 143191525021452
CONSUMIDOR
Consumidor não identificado
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
6757 | C - PIZZA FAMILIA | 1 | UN | 49 | 49,00
6768 | COM BORDA DE CHOCOLATE | 1 | UN | 6,5 | 6,50
940 | SUCO NATURAL | 2 | UN | 5 | 10,00
Valor total R$ | 65,50
Valor descontos R$ | 0,00
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:34